package com.ruoyi.project.pssr.mapper;

import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.pssr.domain.TPssrInstrumentTest;

import java.util.List;

/**
 * 仪联锁测试Mapper接口
 *
 * @author ssy
 * @date 2024-09-18
 */
public interface TPssrInstrumentTestMapper
{
    /**
     * 查询仪联锁测试
     *
     * @param id 仪联锁测试ID
     * @return 仪联锁测试
     */
    public TPssrInstrumentTest selectTPssrInstrumentTestById(Long id);
    public int selectNoConfirmCount(Long subId);

    /**
     * 查询仪联锁测试列表
     *
     * @param tPssrInstrumentTest 仪联锁测试
     * @return 仪联锁测试集合
     */
    
    public List<TPssrInstrumentTest> selectTPssrInstrumentTestList(TPssrInstrumentTest tPssrInstrumentTest);

    /**
     * 新增仪联锁测试
     *
     * @param tPssrInstrumentTest 仪联锁测试
     * @return 结果
     */
    public int insertTPssrInstrumentTest(TPssrInstrumentTest tPssrInstrumentTest);

    /**
     * 修改仪联锁测试
     *
     * @param tPssrInstrumentTest 仪联锁测试
     * @return 结果
     */
    public int updateTPssrInstrumentTest(TPssrInstrumentTest tPssrInstrumentTest);
    public int updateTPssrInstrumentTestByIds(TPssrInstrumentTest tPssrInstrumentTest);


    /**
     * 删除仪联锁测试
     *
     * @param id 仪联锁测试ID
     * @return 结果
     */
    public int deleteTPssrInstrumentTestById(Long id);

    /**
     * 批量删除仪联锁测试
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTPssrInstrumentTestByIds(Long[] ids);
}
